@@ -712,6 +712,7 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
     sno_disk = data['sno_disk']
     sno_ctlplanes = data['sno_ctlplanes'] or baremetal_ctlplane
     sno_workers = data['sno_workers']
+    sno_telco = data['sno_telco']
     ignore_hosts = data['ignore_hosts'] or sslip
     if sno:
         if sno_disk is None:
@@ -756,7 +757,13 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
     if not data['coredns']:
         warning("You will need to provide DNS records for api and ingress on your own")
     keepalived = data['keepalived']
-    if not keepalived:
+    bgp = data['bgp']
+    if bgp:
+        data['keepalived'] = False
+        keepalived = False
+        if not data['bgp_peers']:
+            return {'result': 'failure', 'reason': 'bgp_peers needs to be set'}
+    elif not keepalived:
         warning("You will need to provide LB for api and ingress on your own")
     mdns = data['mdns']
     localhost_fix = data['localhost_fix']
@@ -785,7 +792,7 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
     image = data['image']
     api_ip = data['api_ip']
     cidr = None
-    if provider in virt_providers and keepalived and not sno and api_ip is None:
+    if provider in virt_providers and (keepalived or bgp) and not sno and api_ip is None:
         network = data['network']
         networkinfo = k.info_network(network)
         if not networkinfo:
@@ -1153,13 +1160,12 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
                                             overrides={'role': role, 'node_ip_hint': node_ip_hint})
             with open(f"{clusterdir}/manifests/99-chrony-{role}.yaml", 'w') as f:
                 f.write(hint)
-    manifestsdir = data.get('manifests')
-    manifestsdir = pwd_path(manifestsdir)
-    if os.path.exists(manifestsdir) and os.path.isdir(manifestsdir):
-        for f in glob(f"{manifestsdir}/*.y*ml"):
-            pprint(f"Injecting manifest {f}")
-            copy2(f, f"{clusterdir}/openshift")
-    elif isinstance(manifestsdir, list):
+    if sno_telco:
+        manifestsdir = safe_load(open(f"{plandir}/telco_manifests.yml"))
+    else:
+        manifestsdir = data.get('manifests')
+        manifestsdir = pwd_path(manifestsdir)
+    if isinstance(manifestsdir, list):
         for manifest in manifestsdir:
             f, content = list(manifest.keys())[0], list(manifest.values())[0]
             if not f.endswith('.yml') and not f.endswith('.yaml'):
@@ -1168,6 +1174,10 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
             pprint(f"Injecting manifest {f}")
             with open(f'{clusterdir}/openshift/{f}', 'w') as f:
                 f.write(content)
+    elif os.path.exists(manifestsdir) and os.path.isdir(manifestsdir):
+        for f in glob(f"{manifestsdir}/*.y*ml"):
+            pprint(f"Injecting manifest {f}")
+            copy2(f, f"{clusterdir}/openshift")
     for manifest in glob(f"{clusterdir}/*.yaml"):
         if os.stat(manifest).st_size == 0:
             warning(f"Skipping empty manifest {manifest}")
@@ -1247,10 +1257,11 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
                 _f.write(crondata)
             continue
         if '99-monitoring.yaml' in f:
-            monitoring_retention = data['monitoring_retention']
-            monitoringfile = config.process_inputfile(cluster, f, overrides={'retention': monitoring_retention})
-            with open(f"{clusterdir}/openshift/99-monitoring.yaml", 'w') as _f:
-                _f.write(monitoringfile)
+            if not sno_telco:
+                monitoring_retention = data['monitoring_retention']
+                monitoringfile = config.process_inputfile(cluster, f, overrides={'retention': monitoring_retention})
+                with open(f"{clusterdir}/openshift/99-monitoring.yaml", 'w') as _f:
+                    _f.write(monitoringfile)
             continue
         copy2(f, f"{clusterdir}/openshift")
     if virtualization_nightly:
@@ -1350,7 +1361,7 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
             nm_data = config.process_inputfile(cluster, f"{plandir}/kcli-ipv6.conf.j2", overrides=data)
             sno_files.append({'path': "/etc/NetworkManager/conf.d/kcli-ipv6.conf", 'data': nm_data})
         sno_hostname = data['sno_hostname']
-        if sno_hostname is None:
+        if sno_hostname is not None:
             sno_files.append({'path': "/etc/hostname", 'data': sno_hostname})
         sno_dns = data['sno_dns']
         if sno_dns is None:
