@@ -32,7 +32,7 @@ TUNNELDIR = '/var/www/html'
 TUNNELPORT = 22
 VMUSER = None
 VMPORT = None
-OPENSHIFT_TAG = '4.19'
+OPENSHIFT_TAG = '4.20'
 ALMA = 'https://repo.ifca.es/almalinux'
 BSD = 'https://object-storage.public.mtl1.vexxhost.net/swift/v1/1dbafeefbd4f4c80864414a441e72dd2'
 BSD += '/bsd-cloud-image.org/images/dragonflybsd'
@@ -85,6 +85,7 @@ IMAGES = {'almalinux8': f'{ALMA}/8/cloud/x86_64/images/AlmaLinux-8-GenericCloud-
           'rhcos417': f'{RHCOS}/4.17',
           'rhcos418': f'{RHCOS}/4.18',
           'rhcos419': f'{RHCOS}/4.19',
+          'rhcos420': f'{RHCOS}/4.20',
           'rhcoslatest': f'{RHCOS}/{OPENSHIFT_TAG}',
           'rhel7': 'https://access.redhat.com/downloads/content/69/ver=/rhel---7',
           'rhel8': 'https://access.redhat.com/downloads/content/479/ver=/rhel---8',
@@ -204,7 +205,7 @@ oEO8BRcXIiXiQqW9KnF99fXOiQ/cKYh3kWBBPnuEOhC77Ke5aMlqMNOPULf3PMix
 -----END CERTIFICATE-----"""
 VIRTTYPE = None
 METADATA_FIELDS = ['dnsclient', 'domain', 'image', 'kube', 'kubetype', 'loadbalancer', 'owner', 'plan', 'profile',
-                   'user', 'redfish_iso', 'cluster_network']
+                   'user', 'redfish_iso', 'cluster_network', 'userport']
 VMRULES = []
 VMRULES_STRICT = False
 SECURITYGROUPS = []
